@@ -8,11 +8,12 @@ with qw[Pcore::App::Controller];
 
 requires qw[_build_ext_map];
 
-has api_ver                => ( is => 'ro',   isa => Str );                          # API version
+has api_ver => ( is => 'ro', isa => Maybe [Str] );    # API version
+
 has ext_map                => ( is => 'lazy', isa => HashRef, init_arg => undef );
-has perl_ext_app_namespace => ( is => 'ro',   isa => Str, init_arg => undef );
-has ext_app_namespace      => ( is => 'ro',   isa => Str, init_arg => undef );
-has ext_namespace          => ( is => 'ro',   isa => Str, init_arg => undef );
+has perl_ext_app_namespace => ( is => 'ro',   isa => Str,     init_arg => undef );
+has ext_app_namespace      => ( is => 'ro',   isa => Str,     init_arg => undef );
+has ext_namespace          => ( is => 'ro',   isa => Str,     init_arg => undef );
 
 # this method can be overrided in the child class
 sub BUILD ( $self, $args ) {
@@ -39,8 +40,12 @@ around BUILD => sub ( $orig, $self, $args ) {
 
     my $app_namespace = ref $self->{app};
 
+    my $ext_app;
+
     # this is ExtJS application class
     if ( $self->does('Pcore::App::Controller::ExtJS::App') ) {
+        $ext_app = $self;
+
         $self->{perl_ext_app_namespace} = ref $self;
 
         $self->{ext_app_namespace} = ref($self) =~ s/\A$app_namespace\::Index::/$app_namespace\::/smr;
@@ -48,15 +53,12 @@ around BUILD => sub ( $orig, $self, $args ) {
         $self->{ext_app_namespace} =~ s/:://smg;
 
         $self->{ext_namespace} = $self->{ext_app_namespace};
-
-        $self->{api_ver} //= 'v1';
     }
 
     # this is ExtJS namespace class
     else {
-        # find ExtJS app instance
-        my $ext_app;
 
+        # find ExtJS app instance
         my $parent_class = ref $self;
 
         while (1) {
@@ -86,6 +88,7 @@ around BUILD => sub ( $orig, $self, $args ) {
 
         $self->{ext_namespace} =~ s[/][.]smg;
 
+        # inherit default API version from app, if not defined in current namespace
         $self->{api_ver} //= $ext_app->{api_ver};
     }
 
@@ -95,15 +98,22 @@ around BUILD => sub ( $orig, $self, $args ) {
     # check ext_map
     my $ext_map = $self->ext_map;
 
-    for my $class ( keys $ext_map->{class}->%* ) {
-        die qq["$class" must be lowercase alpha name] if $class !~ /\A[[:lower:]]+\z/sm;
+    for my $class ( keys $ext_map->%* ) {
+        die qq["$class" must be in lowercase alpha name] if $class !~ /\A[[:lower:]]+\z/sm;
 
         die qq["EXT_$class" method is required to generate ExtJS class] if !$self->can("EXT_$class");
 
-        # find real base class name
-        my $real_base_class_name = $Pcore::ExtJS::BOOTSTRAP->{classic}->{class}->{ $ext_map->{class}->{$class} };
+        if ( ref $ext_map->{$class} ne 'HASH' ) {
+            $ext_map->{$class} = {
+                extend => $ext_map->{$class},
+                static => undef,
+            };
+        }
 
-        die qq[ExjJS class "$ext_map->{class}->{$class}" is not registered] if !$real_base_class_name;
+        # find real base class name
+        my $real_base_class_name = $Pcore::ExtJS::BOOTSTRAP->{classic}->{class}->{ $ext_map->{$class}->{extend} };
+
+        die qq[ExjJS class "$ext_map->{$class}->{extend}" is not registered] if !$real_base_class_name;
 
         my $class_name = ucfirst lc $class;
 
@@ -126,6 +136,14 @@ around BUILD => sub ( $orig, $self, $args ) {
 
             $Pcore::ExtJS::BOOTSTRAP->{classic}->{alias_to_class}->{$alias} = $ext_class_name;
         }
+
+        # register ext class as app static class
+        if ( $ext_map->{$class}->{static} ) {
+            $ext_app->{static_classes}->{$ext_class_name} = {
+                ctrl       => $self,
+                class_name => $class_name,
+            };
+        }
     }
 
     return;
@@ -139,7 +157,7 @@ around run => sub ( $orig, $self, $req ) {
 
         my $internal_class_name = lc $extjs_class_name;
 
-        if ( my $extend = $self->{ext_map}->{class}->{$internal_class_name} ) {
+        if ( my $extend = $self->{ext_map}->{$internal_class_name}->{extend} ) {
             my $readable = 1;
 
             # create ExtJS class generation context
@@ -187,7 +205,7 @@ around run => sub ( $orig, $self, $req ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    1 | 93                   | RegularExpressions::ProhibitEnumeratedClasses - Use named character classes ([^A-Za-z] vs. [[:^alpha:]])       |
+## |    1 | 96                   | RegularExpressions::ProhibitEnumeratedClasses - Use named character classes ([^A-Za-z] vs. [[:^alpha:]])       |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
