@@ -1,4 +1,4 @@
-package Pcore::ExtJS v0.9.0;
+package Pcore::ExtJS v0.10.0;
 
 use Pcore -dist, -class;
 use Pcore::ExtJS::Raw;
@@ -198,7 +198,7 @@ sub api_method ( $self, $method_id ) {
     my $map = $self->{app}->{api}->{map};
 
     # add version to relative method id
-    $method_id = "/$self->{namespace}->{api_ver}/$method_id" if substr( $method_id, 0, 1 ) ne q[/];
+    $method_id = "/$self->{namespace}->{api_ver}/$method_id" if substr( $method_id, 0, 1 ) ne q[/] && $self->{namespace}->{api_ver};
 
     my $method = $map->get_method($method_id) // die qq[API method "$method_id" is not exists];
 
